AuthorizationProvider

Trait AuthorizationProvider 

pub trait AuthorizationProvider: Send + Sync {
    // Required method
    fn create_auth_wit<'life0, 'life1, 'async_trait>(
        &'life0 self,
        intent: MessageHashOrIntent,
        chain_info: &'life1 ChainInfo,
    ) -> Pin<Box<dyn Future<Output = Result<AuthWitness, Error>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
}
Provides authorization witnesses for transaction authentication.

This trait is the foundation of the Aztec account model. Implementations produce AuthWitness values that prove the caller is authorized to execute a given intent.

Required Methods

fn create_auth_wit<'life0, 'life1, 'async_trait>( &'life0 self, intent: MessageHashOrIntent, chain_info: &'life1 ChainInfo, ) -> Pin<Box<dyn Future<Output = Result<AuthWitness, Error>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Create an authorization witness for the given intent.

Implementors