pub struct DefaultAccountEntrypoint { /* private fields */ }Expand description
Standard account entrypoint — wraps calls through the account contract.
Implementations
Sourceimpl DefaultAccountEntrypoint
impl DefaultAccountEntrypoint
Sourcepub fn new(address: AztecAddress, auth: Box<dyn AuthorizationProvider>) -> Self
pub fn new(address: AztecAddress, auth: Box<dyn AuthorizationProvider>) -> Self
Create a new account entrypoint for the given address and auth provider.
Sourcepub async fn create_tx_execution_request(
&self,
exec: ExecutionPayload,
gas_settings: GasSettings,
chain_info: &ChainInfo,
options: &DefaultAccountEntrypointOptions,
) -> Result<TxExecutionRequest, Error>
pub async fn create_tx_execution_request( &self, exec: ExecutionPayload, gas_settings: GasSettings, chain_info: &ChainInfo, options: &DefaultAccountEntrypointOptions, ) -> Result<TxExecutionRequest, Error>
Create a full transaction execution request.
Sourcepub async fn wrap_execution_payload(
&self,
exec: ExecutionPayload,
chain_info: &ChainInfo,
options: &DefaultAccountEntrypointOptions,
) -> Result<ExecutionPayload, Error>
pub async fn wrap_execution_payload( &self, exec: ExecutionPayload, chain_info: &ChainInfo, options: &DefaultAccountEntrypointOptions, ) -> Result<ExecutionPayload, Error>
Create a wrapped ExecutionPayload by encoding calls through the account entrypoint.
Sourcepub fn entrypoint_abi() -> FunctionArtifact
pub fn entrypoint_abi() -> FunctionArtifact
Return the ABI for the standard account entrypoint function.
This is useful for account contract implementations that need to include the entrypoint in their contract artifact.
Sourcepub fn address(&self) -> AztecAddress
pub fn address(&self) -> AztecAddress
Get the address of this entrypoint’s account.