pub trait AztecNode: Send + Sync {
Show 28 methods
// Required methods
fn get_node_info<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<NodeInfo, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
Self: 'async_trait;
fn get_block_number<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<u64, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
Self: 'async_trait;
fn get_proven_block_number<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<u64, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
Self: 'async_trait;
fn get_tx_receipt<'life0, 'life1, 'async_trait>(
&'life0 self,
tx_hash: &'life1 TxHash,
) -> Pin<Box<dyn Future<Output = Result<TxReceipt, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait;
fn get_public_logs<'life0, 'async_trait>(
&'life0 self,
filter: PublicLogFilter,
) -> Pin<Box<dyn Future<Output = Result<PublicLogsResponse, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
Self: 'async_trait;
fn send_tx<'life0, 'life1, 'async_trait>(
&'life0 self,
tx: &'life1 Value,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait;
fn get_contract<'life0, 'life1, 'async_trait>(
&'life0 self,
address: &'life1 AztecAddress,
) -> Pin<Box<dyn Future<Output = Result<Option<ContractInstanceWithAddress>, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait;
fn get_contract_class<'life0, 'life1, 'async_trait>(
&'life0 self,
id: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait;
fn get_block_header<'life0, 'async_trait>(
&'life0 self,
block_number: u64,
) -> Pin<Box<dyn Future<Output = Result<Value, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
Self: 'async_trait;
fn get_block<'life0, 'async_trait>(
&'life0 self,
block_number: u64,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
Self: 'async_trait;
fn get_note_hash_membership_witness<'life0, 'life1, 'async_trait>(
&'life0 self,
block_number: u64,
note_hash: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait;
fn get_nullifier_membership_witness<'life0, 'life1, 'async_trait>(
&'life0 self,
block_number: u64,
nullifier: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait;
fn get_low_nullifier_membership_witness<'life0, 'life1, 'async_trait>(
&'life0 self,
block_number: u64,
nullifier: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait;
fn get_public_storage_at<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
block_number: u64,
contract: &'life1 AztecAddress,
slot: &'life2 Fr,
) -> Pin<Box<dyn Future<Output = Result<Fr, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait;
fn get_public_data_witness<'life0, 'life1, 'async_trait>(
&'life0 self,
block_number: u64,
leaf_slot: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait;
fn get_l1_to_l2_message_membership_witness<'life0, 'life1, 'async_trait>(
&'life0 self,
block_number: u64,
entry_key: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait;
fn simulate_public_calls<'life0, 'life1, 'async_trait>(
&'life0 self,
tx: &'life1 Value,
skip_fee_enforcement: bool,
) -> Pin<Box<dyn Future<Output = Result<Value, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait;
fn is_valid_tx<'life0, 'life1, 'async_trait>(
&'life0 self,
tx: &'life1 Value,
) -> Pin<Box<dyn Future<Output = Result<TxValidationResult, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait;
fn get_private_logs_by_tags<'life0, 'life1, 'async_trait>(
&'life0 self,
tags: &'life1 [Fr],
) -> Pin<Box<dyn Future<Output = Result<Value, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait;
fn get_public_logs_by_tags_from_contract<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
contract: &'life1 AztecAddress,
tags: &'life2 [Fr],
) -> Pin<Box<dyn Future<Output = Result<Value, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait;
fn register_contract_function_signatures<'life0, 'life1, 'async_trait>(
&'life0 self,
signatures: &'life1 [String],
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait;
fn get_tx_effect<'life0, 'life1, 'async_trait>(
&'life0 self,
tx_hash: &'life1 TxHash,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait;
fn get_block_hash_membership_witness<'life0, 'life1, 'async_trait>(
&'life0 self,
block_number: u64,
block_hash: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait;
fn find_leaves_indexes<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
block_number: u64,
tree_id: &'life1 str,
leaves: &'life2 [Fr],
) -> Pin<Box<dyn Future<Output = Result<Vec<Option<u64>>, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait;
fn get_tx_by_hash<'life0, 'life1, 'async_trait>(
&'life0 self,
tx_hash: &'life1 TxHash,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait;
// Provided methods
fn get_public_storage_at_by_hash<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
block_hash: &'life1 Fr,
contract: &'life2 AztecAddress,
slot: &'life3 Fr,
) -> Pin<Box<dyn Future<Output = Result<Fr, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Self: 'async_trait { ... }
fn get_public_data_witness_by_hash<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
block_hash: &'life1 Fr,
leaf_slot: &'life2 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait { ... }
fn get_l1_to_l2_message_checkpoint<'life0, 'life1, 'async_trait>(
&'life0 self,
l1_to_l2_message: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<u64>, Error>> + Send + 'async_trait>>
where 'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait { ... }
}Expand description
Public read interface for an Aztec node.
Required Methods
Sourcefn get_node_info<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<NodeInfo, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn get_node_info<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<NodeInfo, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Fetch information about the node’s current state.
Sourcefn get_block_number<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<u64, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn get_block_number<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<u64, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Get the latest block number.
Sourcefn get_proven_block_number<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<u64, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn get_proven_block_number<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<u64, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Get the latest proven block number.
Sourcefn get_tx_receipt<'life0, 'life1, 'async_trait>(
&'life0 self,
tx_hash: &'life1 TxHash,
) -> Pin<Box<dyn Future<Output = Result<TxReceipt, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn get_tx_receipt<'life0, 'life1, 'async_trait>(
&'life0 self,
tx_hash: &'life1 TxHash,
) -> Pin<Box<dyn Future<Output = Result<TxReceipt, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Get the receipt for a transaction.
Sourcefn get_public_logs<'life0, 'async_trait>(
&'life0 self,
filter: PublicLogFilter,
) -> Pin<Box<dyn Future<Output = Result<PublicLogsResponse, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn get_public_logs<'life0, 'async_trait>(
&'life0 self,
filter: PublicLogFilter,
) -> Pin<Box<dyn Future<Output = Result<PublicLogsResponse, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Query public logs matching the given filter.
Sourcefn send_tx<'life0, 'life1, 'async_trait>(
&'life0 self,
tx: &'life1 Value,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn send_tx<'life0, 'life1, 'async_trait>(
&'life0 self,
tx: &'life1 Value,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Send a proven transaction to the network for inclusion.
Sourcefn get_contract<'life0, 'life1, 'async_trait>(
&'life0 self,
address: &'life1 AztecAddress,
) -> Pin<Box<dyn Future<Output = Result<Option<ContractInstanceWithAddress>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn get_contract<'life0, 'life1, 'async_trait>(
&'life0 self,
address: &'life1 AztecAddress,
) -> Pin<Box<dyn Future<Output = Result<Option<ContractInstanceWithAddress>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Get a publicly deployed contract instance by address.
Sourcefn get_contract_class<'life0, 'life1, 'async_trait>(
&'life0 self,
id: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn get_contract_class<'life0, 'life1, 'async_trait>(
&'life0 self,
id: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Get a publicly registered contract class by ID.
Sourcefn get_block_header<'life0, 'async_trait>(
&'life0 self,
block_number: u64,
) -> Pin<Box<dyn Future<Output = Result<Value, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn get_block_header<'life0, 'async_trait>(
&'life0 self,
block_number: u64,
) -> Pin<Box<dyn Future<Output = Result<Value, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Get a block header by block number (0 = latest).
Sourcefn get_block<'life0, 'async_trait>(
&'life0 self,
block_number: u64,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn get_block<'life0, 'async_trait>(
&'life0 self,
block_number: u64,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Get a full block by block number.
Sourcefn get_note_hash_membership_witness<'life0, 'life1, 'async_trait>(
&'life0 self,
block_number: u64,
note_hash: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn get_note_hash_membership_witness<'life0, 'life1, 'async_trait>(
&'life0 self,
block_number: u64,
note_hash: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Get a note-hash membership witness for a leaf at a given block.
Sourcefn get_nullifier_membership_witness<'life0, 'life1, 'async_trait>(
&'life0 self,
block_number: u64,
nullifier: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn get_nullifier_membership_witness<'life0, 'life1, 'async_trait>(
&'life0 self,
block_number: u64,
nullifier: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Get a nullifier membership witness at a given block.
Sourcefn get_low_nullifier_membership_witness<'life0, 'life1, 'async_trait>(
&'life0 self,
block_number: u64,
nullifier: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn get_low_nullifier_membership_witness<'life0, 'life1, 'async_trait>(
&'life0 self,
block_number: u64,
nullifier: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Get the low nullifier membership witness (for non-membership proofs).
Sourcefn get_public_storage_at<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
block_number: u64,
contract: &'life1 AztecAddress,
slot: &'life2 Fr,
) -> Pin<Box<dyn Future<Output = Result<Fr, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait,
fn get_public_storage_at<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
block_number: u64,
contract: &'life1 AztecAddress,
slot: &'life2 Fr,
) -> Pin<Box<dyn Future<Output = Result<Fr, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait,
Read a public storage slot value at a given block.
Sourcefn get_public_data_witness<'life0, 'life1, 'async_trait>(
&'life0 self,
block_number: u64,
leaf_slot: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn get_public_data_witness<'life0, 'life1, 'async_trait>(
&'life0 self,
block_number: u64,
leaf_slot: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Get a merkle witness for a public data leaf.
Sourcefn get_l1_to_l2_message_membership_witness<'life0, 'life1, 'async_trait>(
&'life0 self,
block_number: u64,
entry_key: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn get_l1_to_l2_message_membership_witness<'life0, 'life1, 'async_trait>(
&'life0 self,
block_number: u64,
entry_key: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Get a membership witness for an L1-to-L2 message.
Sourcefn simulate_public_calls<'life0, 'life1, 'async_trait>(
&'life0 self,
tx: &'life1 Value,
skip_fee_enforcement: bool,
) -> Pin<Box<dyn Future<Output = Result<Value, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn simulate_public_calls<'life0, 'life1, 'async_trait>(
&'life0 self,
tx: &'life1 Value,
skip_fee_enforcement: bool,
) -> Pin<Box<dyn Future<Output = Result<Value, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Delegate public call simulation to the node.
Sourcefn is_valid_tx<'life0, 'life1, 'async_trait>(
&'life0 self,
tx: &'life1 Value,
) -> Pin<Box<dyn Future<Output = Result<TxValidationResult, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn is_valid_tx<'life0, 'life1, 'async_trait>(
&'life0 self,
tx: &'life1 Value,
) -> Pin<Box<dyn Future<Output = Result<TxValidationResult, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Validate a simulated transaction.
Get private logs by tags for note discovery.
Get public logs by tags from a specific contract.
Sourcefn register_contract_function_signatures<'life0, 'life1, 'async_trait>(
&'life0 self,
signatures: &'life1 [String],
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn register_contract_function_signatures<'life0, 'life1, 'async_trait>(
&'life0 self,
signatures: &'life1 [String],
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Register contract function signatures for debugging.
Sourcefn get_tx_effect<'life0, 'life1, 'async_trait>(
&'life0 self,
tx_hash: &'life1 TxHash,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn get_tx_effect<'life0, 'life1, 'async_trait>(
&'life0 self,
tx_hash: &'life1 TxHash,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Get the effect of a transaction by its hash.
Returns the full tx effect including nullifiers, block metadata, and positional indexes needed for event validation.
Sourcefn get_block_hash_membership_witness<'life0, 'life1, 'async_trait>(
&'life0 self,
block_number: u64,
block_hash: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn get_block_hash_membership_witness<'life0, 'life1, 'async_trait>(
&'life0 self,
block_number: u64,
block_hash: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Get a block hash membership witness in the archive tree.
Sourcefn find_leaves_indexes<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
block_number: u64,
tree_id: &'life1 str,
leaves: &'life2 [Fr],
) -> Pin<Box<dyn Future<Output = Result<Vec<Option<u64>>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait,
fn find_leaves_indexes<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
block_number: u64,
tree_id: &'life1 str,
leaves: &'life2 [Fr],
) -> Pin<Box<dyn Future<Output = Result<Vec<Option<u64>>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait,
Find leaf indexes in a specified merkle tree.
Sourcefn get_tx_by_hash<'life0, 'life1, 'async_trait>(
&'life0 self,
tx_hash: &'life1 TxHash,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn get_tx_by_hash<'life0, 'life1, 'async_trait>(
&'life0 self,
tx_hash: &'life1 TxHash,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Get a full transaction by its hash.
Returns the wire-format Tx including the serialized kernel public inputs buffer and chonk proof.
Provided Methods
Sourcefn get_public_storage_at_by_hash<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
block_hash: &'life1 Fr,
contract: &'life2 AztecAddress,
slot: &'life3 Fr,
) -> Pin<Box<dyn Future<Output = Result<Fr, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Self: 'async_trait,
fn get_public_storage_at_by_hash<'life0, 'life1, 'life2, 'life3, 'async_trait>(
&'life0 self,
block_hash: &'life1 Fr,
contract: &'life2 AztecAddress,
slot: &'life3 Fr,
) -> Pin<Box<dyn Future<Output = Result<Fr, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
'life3: 'async_trait,
Self: 'async_trait,
Read a public storage slot value at a specific block hash.
Sourcefn get_public_data_witness_by_hash<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
block_hash: &'life1 Fr,
leaf_slot: &'life2 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait,
fn get_public_data_witness_by_hash<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
block_hash: &'life1 Fr,
leaf_slot: &'life2 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<Value>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait,
Get a merkle witness for a public data leaf at a specific block hash.
Sourcefn get_l1_to_l2_message_checkpoint<'life0, 'life1, 'async_trait>(
&'life0 self,
l1_to_l2_message: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<u64>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn get_l1_to_l2_message_checkpoint<'life0, 'life1, 'async_trait>(
&'life0 self,
l1_to_l2_message: &'life1 Fr,
) -> Pin<Box<dyn Future<Output = Result<Option<u64>, Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Get the checkpoint number at which an L1-to-L2 message becomes available.
Returns None if the message is not yet known to the archiver.